from setuptools import setup

setup(name='shikher_probability',
      version='1.0',
      description='Gaussian  and Binomial distributions',      
      packages=['shikher_probability'], 
      author = 'Shikher Srivastava',
      author_email = 'shikher707@gmail.com',
    zip_safe=False)